# spyder-remote-client

![Run tests](https://github.com/Semi-ATE/spyder-remote/workflows/Run%20tests/badge.svg?branch=master)
![Build and Deploy Docs](https://github.com/Semi-ATE/spyder-remote/workflows/Build%20and%20Deploy%20Docs/badge.svg)

Spyder remote client to connect to Spyder kernels via zeroconf.
 
